==> bouml_2.2.2.tar.gz: bouml_2.2.2/src/diagram/CdClassCanvas.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef CDCLASSCANVAS_H
#define CDCLASSCANVAS_H

#include <qobject.h>

#include "DiagramCanvas.h"
#include "MultipleDependency.h"
#include "Settings.h"

#define CLASS_CANVAS_MIN_SIZE 40

class TemplateCanvas;
class RelationData;

class CdClassCanvas : public QObject, public DiagramCanvas,
  		      public MultipleDependency<BasicData> {
  Q_OBJECT
    
  protected:
    TemplateCanvas * templ;
    ClassDiagramSettings settings;
    UmlColor itscolor;
    ClassDrawingMode used_view_mode;
    QString full_name;
    QValueList<BrowserNode *> hidden_attributes;
    QValueList<BrowserNode *> hidden_operations;

    
  protected:
    CdClassCanvas(UmlCanvas * canvas, int id);
  
  public:
    CdClassCanvas(BrowserNode * bn, UmlCanvas * canvas, int x, int y);
    virtual ~CdClassCanvas();
    
    virtual void delete_it();
    
    void compute_size();
    virtual BasicData * add_relation(UmlCode, DiagramItem *);
    virtual bool has_relation(BasicData *) const;
    void draw_all_relations(CdClassCanvas * end = 0);

    virtual void draw(QPainter & p);
    virtual void change_scale(double);
    
    virtual UmlCode type() const;
    virtual void delete_available(bool & in_model, bool & out_model) const;
    virtual bool alignable() const;
    virtual bool copyable() const;
    virtual void remove(bool from_model);
    virtual void open();
    virtual void menu(const QPoint&);
    virtual bool may_start(UmlCode &) const;
    virtual bool may_connect(UmlCode l, const DiagramItem * dest) const;
    virtual void connexion(UmlCode, DiagramItem *, const QPoint &, const QPoint &);
    virtual void prepare_for_move();
    virtual void moveBy(double dx, double dy);
    virtual void set_z(double z);	// only called by upper() & lower()
    
    virtual void save(QTextStream  & st, bool ref, QString & warning) const;
    
    static CdClassCanvas * read(char * &, UmlCanvas *, char *);
    
  private slots:
    void modified();	// canvas must be updated
    void deleted();	// the class is deleted
};

#endif

==> bouml_2.5.2.tar.gz: bouml_2.5.2/src/diagram/CdClassCanvas.h <==
// *************************************************************************
//
// Copyright (C) 2004,2005 Bruno PAGES  All rights reserved.
//
// This file is part of the BOUML Uml Toolkit.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// e-mail : bouml@free.fr
// home   : http://bouml.free.fr
//
// *************************************************************************

#ifndef CDCLASSCANVAS_H
#define CDCLASSCANVAS_H

#include <qobject.h>

#include "DiagramCanvas.h"
#include "MultipleDependency.h"
#include "Settings.h"

#define CLASS_CANVAS_MIN_SIZE 40

class TemplateCanvas;
class RelationData;

class CdClassCanvas : public QObject, public DiagramCanvas,
  		      public MultipleDependency<BasicData> {
  Q_OBJECT
    
  protected:
    TemplateCanvas * templ;
    ClassDiagramSettings settings;
    UmlColor itscolor;
    UmlColor used_color;
    ClassDrawingMode used_view_mode;
    QString full_name;
    QValueList<BrowserNode *> hidden_attributes;
    QValueList<BrowserNode *> hidden_operations;

    
  protected:
    CdClassCanvas(UmlCanvas * canvas, int id);
  
  public:
    CdClassCanvas(BrowserNode * bn, UmlCanvas * canvas, int x, int y);
    virtual ~CdClassCanvas();
    
    virtual void delete_it();
    
    void compute_size();
    virtual BasicData * add_relation(UmlCode, DiagramItem *);
    virtual bool has_relation(BasicData *) const;
    void draw_all_relations(CdClassCanvas * end = 0);

    virtual void draw(QPainter & p);
    virtual void change_scale(double);
    
    virtual UmlCode type() const;
    virtual void delete_available(bool & in_model, bool & out_model) const;
    virtual bool alignable() const;
    virtual bool copyable() const;
    virtual void remove(bool from_model);
    virtual void open();
    virtual void menu(const QPoint&);
    virtual bool may_start(UmlCode &) const;
    virtual bool may_connect(UmlCode l, const DiagramItem * dest) const;
    virtual void connexion(UmlCode, DiagramItem *, const QPoint &, const QPoint &);
    virtual void prepare_for_move(bool on_resize);
    virtual void moveBy(double dx, double dy);
    virtual void set_z(double z);	// only called by upper() & lower()
    
    virtual void save(QTextStream  & st, bool ref, QString & warning) const;
    
    static CdClassCanvas * read(char * &, UmlCanvas *, char *);
    
  private slots:
    void modified();	// canvas must be updated
    void deleted();	// the class is deleted
};

#endif
